[Author Prev][Author Next][Thread Prev][Thread Next][Author Index][Thread Index]
[tor-commits] [stem/master] Add HSDescReason.QUERY_RATE_LIMITED
commit 206b50519dbdf2881cf72cf9f0cbae453db08ede
Author: Damian Johnson <atagar@xxxxxxxxxxxxxx>
Date: Sun Apr 28 12:53:18 2019 -0700
Add HSDescReason.QUERY_RATE_LIMITED
Updating our enum with a newly introduced reason.
https://gitweb.torproject.org/torspec.git/commit/?id=bd80679
---
stem/__init__.py | 24 ++++++++++++++----------
1 file changed, 14 insertions(+), 10 deletions(-)
diff --git a/stem/__init__.py b/stem/__init__.py
index 1d3436f1..70870e8e 100644
--- a/stem/__init__.py
+++ b/stem/__init__.py
@@ -468,16 +468,20 @@ Library for working with the tor process.
.. versionchanged:: 1.6.0
Added the QUERY_NO_HSDIR reason.
- =================== ===========
- HSDescReason Description
- =================== ===========
- **BAD_DESC** descriptor was unparseable
- **QUERY_REJECTED** hidden service directory refused to provide the descriptor
- **UPLOAD_REJECTED** descriptor was rejected by the hidden service directory
- **NOT_FOUND** descriptor with the given identifier wasn't found
- **QUERY_NO_HSDIR** no hidden service directory was found
- **UNEXPECTED** failure type is unknown
- =================== ===========
+ .. versionchanged:: 1.8.0
+ Added the QUERY_RATE_LIMITED reason.
+
+ ======================= ===========
+ HSDescReason Description
+ ======================= ===========
+ **BAD_DESC** descriptor was unparseable
+ **QUERY_REJECTED** hidden service directory refused to provide the descriptor
+ **UPLOAD_REJECTED** descriptor was rejected by the hidden service directory
+ **NOT_FOUND** descriptor with the given identifier wasn't found
+ **QUERY_NO_HSDIR** no hidden service directory was found
+ **QUERY_RATE_LIMITED** request was throttled
+ **UNEXPECTED** failure type is unknown
+ ======================= ===========
.. data:: HSAuth (enum)
_______________________________________________
tor-commits mailing list
tor-commits@xxxxxxxxxxxxxxxxxxxx
https://lists.torproject.org/cgi-bin/mailman/listinfo/tor-commits